@@ -1,7 +1,7 @@
 ### R code from vignette source 'FLLat_tutorial.rnw'
 
 ###################################################
-### code chunk number 1: FLLat_tutorial.rnw:105-109
+### code chunk number 1: FLLat_tutorial.rnw:110-114
 ###################################################
 library(FLLat)
 data(simaCGH)
@@ -10,7 +10,7 @@ plot(result.pve)
 
 
 ###################################################
-### code chunk number 2: FLLat_tutorial.rnw:131-134
+### code chunk number 2: FLLat_tutorial.rnw:139-142
 ###################################################
 result.bic <- FLLat.BIC(simaCGH,J=5)
 result.bic$lam1
@@ -18,22 +18,33 @@ result.bic$lam2
 
 
 ###################################################
-### code chunk number 3: FLLat_tutorial.rnw:145-146
+### code chunk number 3: FLLat_tutorial.rnw:153-154
 ###################################################
 plot(result.bic$opt.FLLat)
 
 
 ###################################################
-### code chunk number 4: FLLat_tutorial.rnw:156-157
+### code chunk number 4: FLLat_tutorial.rnw:164-165
 ###################################################
-plot(result.bic$opt.FLLat,what="weights")
+plot(result.bic$opt.FLLat,type="weights")
 
 
 ###################################################
-### code chunk number 5: FLLat_tutorial.rnw:217-220
+### code chunk number 5: FLLat_tutorial.rnw:227-230
 ###################################################
 result.fdr <- FLLat.FDR(simaCGH,result.bic$opt.FLLat)
 result.fdr$thresh.control
 plot(result.fdr)
 
 
+###################################################
+### code chunk number 6: FLLat_tutorial.rnw:267-273
+###################################################
+tr.dat <- simaCGH[,1:15]
+tst.dat <- simaCGH[,16:20]
+result.tr <- FLLat(tr.dat,J=5,lam1=1,lam2=9)
+tst.pred <- predict(result.tr,newY=tst.dat)
+plot(tst.dat[,1],xlab="Probe",ylab="Y")
+lines(tst.pred$pred.Y[,1],col="red",lwd=3)
+
+
